<?php

namespace Drupal\media_thumbnails_word\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Formulaire de configuration pour définir le chemin vers la librairie mpdf.
 */
class MediaThumbnailsWordSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['media_thumbnails_word.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'media_thumbnails_word_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('media_thumbnails_word.settings');

    $form['mpdf_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Path to mPDF library'),
      '#default_value' => $config->get('mpdf_path'),
      '#description' => $this->t('Enter the full path to the mPDF library, ex "/var/www/vendor/mdpf/mpdf".'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $mpdf_path = $form_state->getValue('mpdf_path');

    // Vérification si le dossier existe
    if (!is_dir($mpdf_path)) {
      \Drupal::messenger()->addError($this->t('The specified mPDF library directory does not exist: @path', ['@path' => $mpdf_path]));
      return;
    }
    $this->config('media_thumbnails_word.settings')
      ->set('mpdf_path', $mpdf_path)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
