<?php

namespace Drupal\media_thumbnails_word\Plugin\MediaThumbnail;

use Drupal\media_thumbnails\Plugin\MediaThumbnailBase;

use \PhpOffice\PhpWord\IOFactory as wordIOFactory;

/**
 * Media thumbnail plugin for Office documents.
 *
 * @MediaThumbnail(
 *   id = "media_thumbnail_word",
 *   label = @Translation("Media Thumbnail Word"),
 *   mime = {
 *     "application/msword",
 *     "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
 *   }
 * )
 */
class MediaThumbnailsWord extends MediaThumbnailBase {

  /**
   * Creates a managed thumbnail file using the passed source file uri.
   *
   * {@inheritdoc}
   */
  public function createThumbnail($sourceUri) {

    // Check the required php extension.
    if (!extension_loaded('imagick')) {
      $this->logger->warning($this->t('Imagick php extension not loaded.'));
      return NULL;
    }


    $config = $this->config->getEditable('media_thumbnails_word.settings');

    //src : https://stackoverflow.com/questions/7708534/create-a-thumbnail-preview-of-documents-pdf-doc-xls-etc-in-php-lamp
    $pathPdf = NULL;

    // Imagick doesn't support stream wrappers!
    $path = $this->fileSystem->realpath($sourceUri);

    $ext = pathinfo($sourceUri, PATHINFO_EXTENSION); // To get extension

    // Read the pdf.
    $im = new \Imagick();

    if ($ext == 'doc' || $ext == 'docx') {
      $mpdfLibPath = $config->get('mpdf_path');
      if (empty($mpdfLibPath)) {
        $url = \Drupal::url('media_thumbnails_word.settings_form');
        $this->logger->warning($this->t('The mPDF library path is not set. Please configure it <a href=":url">here</a>.', [':url' => $url]));
        return NULL;
      }

      // Set the PDF library to use
      \PhpOffice\PhpWord\Settings::setPdfRendererPath($mpdfLibPath);
      \PhpOffice\PhpWord\Settings::setPdfRendererName('MPDF');

      // Load the Word document
      $phpWord = wordIOFactory::load($path);

      // Set up the PDF writer
      $writer = \PhpOffice\PhpWord\IOFactory::createWriter($phpWord, 'PDF');

      // Set the output file path
      $pathPdf = $sourceUri . '.pdf';

      // Write the PDF to the output file path
      $writer->save($pathPdf);
    }

    // Imagick doesn't support stream wrappers!
    $pathPdf = $this->fileSystem->realpath($pathPdf);

    try {
      $im->readimage($pathPdf . '[0]');
    }
    catch (\ImagickException $e) {
      $this->logger->warning($e->getMessage() . ' $pathPdf = ' . $pathPdf);
      return NULL;
    }

    // Handle transparency stuff.
    $im->setImageBackgroundColor('white');
    $im->setImageAlphaChannel(\Imagick::ALPHACHANNEL_REMOVE);
    try {
      $im->mergeImageLayers(\Imagick::LAYERMETHOD_FLATTEN);
    }
    catch (\ImagickException $e) {
      $this->logger->warning($e->getMessage());
      return NULL;
    }

    // Resize the thumbnail to the globally configured width.
    $width = $this->configuration['width'] ?? 500;
    if ($im->getImageWidth() > $width) {
      try {
        $im->scaleImage($width, 0);
      }
      catch (\ImagickException $e) {
        $this->logger->warning($e->getMessage());
        return NULL;
      }
    }

    // Convert the image to JPG.
    $im->setImageFormat('jpg');
    $image = $im->getImageBlob();
    $im->clear();
    $im->destroy();

    // Return a new managed file object using the generated thumbnail.
    return \Drupal::service('file.repository')->writeData($image, $sourceUri . '.jpg');
  }

}
